==> v10.0.1.tar.gz: bookmarks/l10n/zh_HK.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "書籤",
    "You bookmarked \"%s\"" : "您已建立書籤 \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s 建立書籤 \"%2$s\"",
    "Someone bookmarked \"%s\"" : "有人建立書籤 \"%s\"",
    "You deleted \"%s\"" : "您已刪除 \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s 已刪除 \"%2$s\"",
    "Someone deleted \"%s\"" : "有人刪除 \"%s\"",
    "You created folder \"%s\"" : "您已建立資料夾 \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s 已建立資料夾 \"%2$s\"",
    "Someone created folder \"%s\"" : "有人建立資料夾 \"%s\"",
    "You moved folder \"%s\"" : "您已移動資料夾 \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s 已移動資料夾 \"%2$s\"",
    "Someone moved folder \"%s\"" : "有人移動資料夾 \"%s\"",
    "You deleted folder \"%s\"" : "您已刪除資料夾 \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s 已刪除資料夾 \"%2$s\"",
    "Someone deleted folder \"%s\"" : "有人刪除資料夾 \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "您已與 %2$s 共用 \"%1$s\" ",
    "You shared folder \"%s\" with someone" : "您已與某人共用 \"%s\"",
    "%1$s shared folder \"%2$s\" with you" : "%1$s 已共用資料夾 \"%2$s\" 給您",
    "Someone shared folder \"%s\" with you" : "有人共用資料夾 \"%s\" 給您",
    "You unshared folder \"%1$s\" with %2$s" : "您已取消與 %2$s 共用的資料夾 \"%1$s\"",
    "You unshared folder \"%s\" with someone" : "您已取消與某人共用的資料夾 \"%s\"",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s 已取消與您共用的資料夾 \"%2$s\" ",
    "Someone unshared folder \"%s\" with you" : "某人已取消與你共用的資料夾 \"%s\"",
    "No file provided for import" : "無匯入檔案",
    "Unsupported file type for import" : "匯入不支援的檔案格式",
    "Bookmarks shared by %s" : "由 %s 共用的書籤",
    "Frequent bookmarks" : "常用書籤",
    "Recent bookmarks" : "最近使用的書籤",
    "Bookmark" : "書籤",
    "Bookmark deleted" : "書籤已刪除",
    "Bookmark created" : "書籤已建立",
    "Bookmark moved" : "書籤已移動",
    "Bookmark updated" : "書籤已更新",
    "Create bookmark" : "已建立書籤",
    "Takes a link and adds it to your collection of bookmarks." : "將連結添加到您的書籤收藏。",
    "A Bookmark manager for Nextcloud" : "Nextcloud上的書籤管理員",
    "- 📂 Browse and filter your bookmarks via tags and folders and add personal notes\n- 🔍 Built-in full-text search integrated into Nextcloud's unified search\n- 👪 Share bookmarks with other users as well as publicly\n- 💡 Keep track of changes in the activity stream\n- ☠ Easily find broken links\n- 📔 All your links are automatically archived for full-text search and in case they are depublished\n- 📲 Access your bookmarks anywhere, on desktop Browsers and on your phone, via a variety of sync clients\n- 💼 Built-in Dashboard widgets for frequent and recent links\n- ⚛ Easily generate public and private RSS feeds of your collections\n\nRequirements:\n - PHP v7.3+\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - Nextcloud v20+" : "- 📂 通過標籤或資料夾瀏覽和過濾您的書籤，並添加個人筆記\n- 🔍 內置全文搜索，集成到 Nextcloud 的統一搜索中\n- 👪 與其他用戶和公眾分享書籤\n- 💡 跟踪活動流的變化\n- ☠ 輕鬆找到斷開的連結\n- 📔您的所有連結都會自動存檔以進行全文搜索，以防它們被取消發布\n- 📲 通過各種同步客戶端在桌面瀏覽器和手機上隨時隨地訪問您的書籤\n- 💼 內置儀表板小部件，用於顯示頻繁和最近的連結\n- ⚛ 輕鬆生成收藏的公共和私人 RSS 提要\n\n要求：\n- PHP v7.3+\n- PHP extensions:\n- intl: *\n- mbstring: *\n- Nextcloud v20+",
    "Enter new title" : "輸入新的標題",
    "Select bookmark" : "選擇書籤",
    "Details" : "細節",
    "Rename" : "重新命名",
    "Move" : "移動",
    "Add to folders" : "添加到資料夾",
    "Delete" : "刪除",
    "Do you really want to delete this bookmark?" : "您確定要刪除此書籤嗎？",
    "Content pending" : "內容待定",
    "This content is being downloaded for offline use. Please check back later." : "正在下載此內容以供離線使用。請稍後再檢查。",
    "Open all selected" : "開啟所有選擇對象",
    "Move selection" : "移動選擇",
    "Edit tags of selection" : "編輯所選項目的標籤",
    "Delete selection" : "刪除選擇",
    "Select all" : "全選",
    "Cancel selection" : "取消選擇",
    "Selected {folders} folders and {bookmarks} bookmarks" : "所選 {folders} 資料夾 和 {bookmarks} 書籤",
    "Do you really want to delete these items?" : "您確定要刪除這些項目嗎？",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["已選擇 %n 個書籤"],
    "_Selected %n folder_::_Selected %n folders_" : ["已選擇 %n 個資料夾"],
    "Go back" : "返回",
    "Share folder" : "分享資料夾",
    "Select one or more tags" : "選擇一個或是多個標籤",
    "New" : "新增",
    "New bookmark" : "新增書籤",
    "New folder" : "新增資料夾",
    "Change to grid view" : "切換至網格檢視",
    "Change to list view" : "切換到列表視圖",
    "Copy RSS Feed of current view" : "複製當前視圖的RSS Feed",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS feed 需要使用您的 Nextcloud 身份驗證進行驗證",
    "Sort by created date" : "按創建日期排序",
    "Sort by last modified" : "按修改日期排序",
    "Sort by title" : "按標題排序",
    "Sort by click count" : "按點擊次數排序",
    "Sort by manual order" : "手動排序",
    "RSS feed copied" : "RSS feed 已複製",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["將 %n 書籤添加到新資料夾"],
    "Enter a link" : "輸入連結",
    "Enter a title" : "輸入標題",
    "No bookmarks found" : "未發現書籤",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} 資料夾和 {bookmarks} 書籤",
    "_%n bookmark_::_%n bookmarks_" : ["%n 書籤"],
    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
    "Select folder" : "選擇資料夾",
    "Enter folder title" : "輸入資料夾標題",
    "Shared by {user}" : "由 {user} 分享",
    "Rename folder" : "重新命名資料夾",
    "Move folder" : "移動資料夾",
    "Delete folder" : "刪除資料夾",
    "Do you really want to delete this folder?" : "您確定要刪除此資料夾嗎？",
    "Choose folder" : "選擇資料夾",
    "Submit" : "遞交",
    "Cancel" : "取消",
    "Deleting bookmarks" : "刪除書籤",
    "Deleting selection" : "刪除選擇",
    "Importing bookmarks" : "匯入書籤",
    "Moving selection" : "移動選擇",
    "Adding selection to folders" : "將所選項目添加到資料夾",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["正在移動%n資料夾和一些書籤"],
    "_Moving %n folder_::_Moving %n folders_" : ["移動%n個資料夾"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["正在移動%n個書籤"],
    "All bookmarks" : "所有書籤",
    "Recent" : "最新",
    "Files" : "檔案",
    "Broken links" : "連結斷開",
    "New tag" : "新標籤",
    "Search tags" : "搜索標籤",
    "Untagged" : "未標記",
    "{used} bookmarks of {available} available" : "{available} 個可用書籤中的 {used} 個。",
    "No bookmarked files" : "沒有已加書籤的檔案",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "照片或PDF等檔案的書籤將自動保存到您的Nextcloud檔案中，因此即使連結脫機，您仍然可以找到它們。",
    "No bookmarks here" : "無書籤",
    "Start by importing bookmarks from a file or synchronizing your browser bookmarks with this app" : "首先從檔案中導入書籤，或與此瀏覽器同步瀏覽器書籤",
    "Import bookmarks" : "匯入書籤",
    "Sync with your browser" : "與瀏覽器同步",
    "Import" : "匯入",
    "Export" : "導出",
    "Archive path" : "封存路徑",
    "Enter the path of a folder where bookmarked files should be stored" : "輸入應該存儲書籤檔案的資料夾的路徑",
    "Client apps" : "客戶端 apps",
    "Also check out the collection of client apps that integrate with this app: " : "還請檢查與此應用程序集成的客戶端應用程序的集合：",
    "Install web app on device" : "在設備上安裝 web 應用程式",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "您可以在設備主屏幕上安裝此應用程序以快速訪問手機上的書籤。如果您不喜歡它，您可以輕鬆地再次從主屏幕中刪除該應用程式。",
    "Install on home screen" : "在主屏幕上安裝",
    "Bookmarklet" : "書籤",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "將此拖拉到您瀏覽器書籤中且點擊它以快速為網頁添加書籤",
    "Add to {instanceName}" : "加到 {instanceName}",
    "Clear data" : "清除資料",
    "Permanently remove all bookmarks from your account." : "從您的賬戶中永久刪除所有書籤。",
    "Delete all bookmarks" : "刪除所有書籤",
    "Do you really want to delete all your bookmarks?" : "您確定要刪除所有的書籤嗎？",
    "Please select \"Add to home screen\" in your browser menu" : "請在瀏覽器菜單中選擇“添加到主屏幕”",
    "Title" : "標題",
    "Link" : "連結",
    "Untitled folder" : "未命名資料夾",
    "Tags" : "標籤",
    "Select tags and create new ones" : "選擇標籤或創建新標籤",
    "Notes" : "註釋",
    "Notes for this bookmark …" : "此書籤的註釋...",
    "Archived file" : "已封存檔案",
    "Open file" : "開啟檔案",
    "Open file location" : "開啟檔案位置",
    "Created {time} ago" : "在 {time} 前創建",
    "Created on {date}" : "創建於 {date} ",
    "Owner" : "擁有者",
    "Sharing" : "分享",
    "Select a user or group" : "選擇用戶或群組",
    "Share link" : "分享連結",
    "Reading allowed" : "允許讀取",
    "Copy link" : "複製連結",
    "Copy RSS feed" : "複製 RSS feed",
    "Delete link" : "刪除連結",
    "Create public link" : "建立公共連結",
    "Resharing allowed" : "允許轉貼分享",
    "Editing allowed" : "允許編輯",
    "Allow editing" : "允許編輯",
    "Allow resharing" : "允許轉貼分享",
    "Remove share" : "移除分享",
    "Link copied" : "連結已複製",
    "Privacy" : "私隱",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "書籤將嘗試存取您添加的網頁，以自動添加有關它們的信息。",
    "Enable accessing and collecting information from the web pages you add" : "從您增加的網頁啟用存取及收集資訊",
    "Performance" : "效能",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "在具有大量用戶的安裝中，限制每個賬戶的書籤數量可能很有用。",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "每個帳號可以允許的書籤最大數量。（0是無限制; 預設是無限制）",
    "Previews" : "預覽",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "為了顯示您添加了書籤的網站的真實屏幕截圖，Bookmarks 可以使用第三方服務來生成預覽。",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "您可以免費在 screeenly。com 註冊或是設定您自己的伺服器。",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API key",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the pageres cli on your server and bookmarks will find it." : "只需在您的伺服器上安裝 pageres cli，書籤就會找到它。",
    "Failed to load settings" : "載入設定失敗",
    "Failed to save settings" : "設定儲存失敗",
    "Add a bookmark" : "新增書籤",
    "This URL is already bookmarked! Overwrite?" : "此連結已存在，是否複寫？",
    "Enter bookmark title" : "輸入書籤標題",
    "Enter bookmark URL" : "輸入書籤URL",
    "Folder" : "資料夾",
    "Root Folder" : "根資料夾",
    "Save" : "儲存",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "默認情況下，網絡存取處於停用狀態。轉到書籤應用程式的管理員設置，以啟用獲取預覽和網站圖標的功能。",
    "Failed to count unavailable bookmarks" : "無法點算不可用的書籤",
    "Failed to count archived bookmarks" : "無法點算已封存的書籤",
    "Failed to load bookmark" : "載入書籤失敗",
    "Failed to find existing bookmark" : "尋找現存的書籤失敗",
    "Failed to create bookmark" : "建立書籤失敗",
    "Failed to save bookmark" : "儲存書籤失敗",
    "Failed to move bookmark" : "移動書籤失敗",
    "Failed to copy bookmark" : "無法複製書籤",
    "Failed to delete bookmark" : "刪除書籤失敗",
    "Failed to rename tag" : "重新命名標籤失敗",
    "Failed to load tags" : "載入標記失敗",
    "Failed to load folders" : "載入資料夾失敗",
    "Failed to delete folder" : "刪除資料夾失敗",
    "Failed to create folder" : "建立資料夾失敗",
    "Failed to fetch bookmarks." : "擷取書籤失敗",
    "Failed to change setting" : "變更設定失敗",
    "Failed to load setting {key}" : "載入設定失敗 {key}",
    "Failed to update share {shareId}" : "更新分享失敗 {shareId}",
    "Failed to delete share {shareId}" : "無法刪除分享 {shareId}",
    "Bookmarks feed" : "Bookmarks feed"
},
"nplurals=1; plural=0;");

==> v10.5.1.tar.gz: bookmarks/l10n/zh_HK.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "書籤",
    "You bookmarked \"%s\"" : "您已建立書籤 \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s 建立書籤 \"%2$s\"",
    "Someone bookmarked \"%s\"" : "有人建立書籤 \"%s\"",
    "You deleted \"%s\"" : "您已刪除 \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s 已刪除 \"%2$s\"",
    "Someone deleted \"%s\"" : "有人刪除 \"%s\"",
    "You created folder \"%s\"" : "您已建立資料夾 \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s 已建立資料夾 \"%2$s\"",
    "Someone created folder \"%s\"" : "有人建立資料夾 \"%s\"",
    "You moved folder \"%s\"" : "您已移動資料夾 \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s 已移動資料夾 \"%2$s\"",
    "Someone moved folder \"%s\"" : "有人移動資料夾 \"%s\"",
    "You deleted folder \"%s\"" : "您已刪除資料夾 \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s 已刪除資料夾 \"%2$s\"",
    "Someone deleted folder \"%s\"" : "有人刪除資料夾 \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "您已與 %2$s 共用 \"%1$s\" ",
    "You shared folder \"%s\" with someone" : "您已與某人共用 \"%s\"",
    "%1$s shared folder \"%2$s\" with you" : "%1$s 已共用資料夾 \"%2$s\" 給您",
    "Someone shared folder \"%s\" with you" : "有人共用資料夾 \"%s\" 給您",
    "You unshared folder \"%1$s\" with %2$s" : "您已取消與 %2$s 共用的資料夾 \"%1$s\"",
    "You unshared folder \"%s\" with someone" : "您已取消與某人共用的資料夾 \"%s\"",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s 已取消與您共用的資料夾 \"%2$s\" ",
    "Someone unshared folder \"%s\" with you" : "某人已取消與你共用的資料夾 \"%s\"",
    "No file provided for import" : "無匯入檔案",
    "Unsupported file type for import" : "匯入不支援的檔案格式",
    "Bookmarks Backups" : "書籤備份",
    "Bookmarks shared by %s" : "由 %s 共用的書籤",
    "Frequent bookmarks" : "常用書籤",
    "Recent bookmarks" : "最近使用的書籤",
    "Bookmark" : "書籤",
    "Bookmark deleted" : "書籤已刪除",
    "Bookmark created" : "書籤已建立",
    "Bookmark moved" : "書籤已移動",
    "Bookmark updated" : "書籤已更新",
    "Create bookmark" : "已建立書籤",
    "Takes a link and adds it to your collection of bookmarks." : "將連結添加到您的書籤收藏。",
    "A Bookmark manager for Nextcloud" : "Nextcloud上的書籤管理員",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- 🔍 Full-text search\n- 📲 Synchronize with all your browsers and devices\n- 👪 Share bookmarks with other users and publicly\n- ☠ Find broken links\n- ⚛ Generate RSS feeds of your collections\n- 📔 Read archived versions of your links in case they are depublished\n- 💬 Create new bookmarks directly from within Nextcloud Talk\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP v7.3+\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - Nextcloud v20+" : "- 📂 將書籤分類到文件夾中\n- 🏷 添加標籤和個人筆記\n- 🔍全文搜索\n- 📲 與您的所有瀏覽器和設備同步\n- 👪 與其他用戶和公開分享書籤\n- ☠ 查找斷開的鏈接\n- ⚛ 生成收藏的 RSS 提要\n- 📔 閱讀鏈接的存檔版本，以防它們被取消發布\n- 💬 直接在 Nextcloud Talk 中創建新書籤\n- 💼 用於頻繁和最近鏈接的內置儀表板小部件\n\n要求：\n- PHP v7.3+\n- PHP 擴展：\n- 國際：*\n- mbstring：*\n- Nextcloud v20+",
    "Enter new title" : "輸入新的標題",
    "Select bookmark" : "選擇書籤",
    "Details" : "細節",
    "Rename" : "重新命名",
    "Copy link" : "複製連結",
    "Move" : "移動",
    "Add to folders" : "添加到資料夾",
    "Delete" : "刪除",
    "Do you really want to delete this bookmark?" : "您確定要刪除此書籤嗎？",
    "Link copied to clipboard" : "已複製連結至剪貼板",
    "Content pending" : "內容待定",
    "This content is being downloaded for offline use. Please check back later." : "正在下載此內容以供離線使用。請稍後再檢查。",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "網絡上的檔案（如照片或 PDF）的書籤將自動保存到您的 Nextcloud 檔案中，因此即使連結離線，您也仍然可以找到它們。",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "已加入書籤的連結會定期檢查，無法存取的連結就會在此列出。",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "您可以與其他人分享書籤資料夾。此處列出了與您分享的所有資料夾。",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "一個書籤可以同時位於多個文件夾中。 更新它將更新所有副本。 為方便起見，此處列出了所有重複的書籤。",
    "Open all selected" : "開啟所有選擇對象",
    "Move selection" : "移動選擇",
    "Edit tags of selection" : "編輯所選項目的標籤",
    "Delete selection" : "刪除選擇",
    "Select all" : "全選",
    "Cancel selection" : "取消選擇",
    "Selected {folders} folders and {bookmarks} bookmarks" : "所選 {folders} 資料夾 和 {bookmarks} 書籤",
    "Do you really want to delete these items?" : "您確定要刪除這些項目嗎？",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["已選擇 %n 個書籤"],
    "_Selected %n folder_::_Selected %n folders_" : ["已選擇 %n 個資料夾"],
    "Go back" : "返回",
    "Share folder" : "分享資料夾",
    "Select one or more tags" : "選擇一個或是多個標籤",
    "New" : "新增",
    "New bookmark" : "新增書籤",
    "New folder" : "新增資料夾",
    "Change to grid view" : "切換至網格檢視",
    "Change to list view" : "切換到列表視圖",
    "Copy RSS Feed of current view" : "複製當前視圖的RSS Feed",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS feed 需要使用您的 Nextcloud 身份驗證進行驗證",
    "Sort by created date" : "按創建日期排序",
    "Sort by last modified" : "按修改日期排序",
    "Sort by title" : "按標題排序",
    "Sort by click count" : "按點擊次數排序",
    "Sort by manual order" : "手動排序",
    "RSS feed copied" : "RSS feed 已複製",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["將 %n 書籤添加到新資料夾"],
    "Enter a link" : "輸入連結",
    "Enter a title" : "輸入標題",
    "No bookmarks found" : "未發現書籤",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} 資料夾和 {bookmarks} 書籤",
    "_%n bookmark_::_%n bookmarks_" : ["%n 書籤"],
    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
    "Welcome to Bookmarks" : "歡迎來到 Bookmarks",
    "This app allows you to manage links to your favorite places on the web." : "這個應用程式允許您管理指向您在網絡上最喜歡的地方的連結。",
    "Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "將您的書籤分類到資料夾中，用標籤標記它們並與他人分享！該應用程式會定期檢查您所有連結的可用性並顯示不可用的連結。如果您在網絡上添加指向檔案的鏈接，該檔案將自動下載到您的 Nextcloud 檔案中。您還可以導入從其他服務導出的書籤，或直接將所有瀏覽器中的書籤與此應用程式同步。",
    "Add a bookmark" : "新增書籤",
    "Import bookmarks" : "匯入書籤",
    "Sync with your browser" : "與瀏覽器同步",
    "Select folder" : "選擇資料夾",
    "Enter folder title" : "輸入資料夾標題",
    "Shared by {user}" : "由 {user} 分享",
    "Rename folder" : "重新命名資料夾",
    "Move folder" : "移動資料夾",
    "Delete folder" : "刪除資料夾",
    "Do you really want to delete this folder?" : "您確定要刪除此資料夾嗎？",
    "Choose folder" : "選擇資料夾",
    "Submit" : "遞交",
    "Cancel" : "取消",
    "Deleting bookmarks" : "刪除書籤",
    "Deleting selection" : "刪除選擇",
    "Importing bookmarks" : "匯入書籤",
    "Moving selection" : "移動選擇",
    "Adding selection to folders" : "將所選項目添加到資料夾",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["正在移動%n資料夾和一些書籤"],
    "_Moving %n folder_::_Moving %n folders_" : ["移動%n個資料夾"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["正在移動%n個書籤"],
    "All bookmarks" : "所有書籤",
    "Recent" : "最新",
    "Shared with you" : "與您分享",
    "Files" : "檔案",
    "Duplicates" : "複本",
    "Broken links" : "連結斷開",
    "New tag" : "新標籤",
    "Search tags" : "搜索標籤",
    "Untagged" : "未標記",
    "{used} bookmarks of {available} available" : "{available} 個可用書籤中的 {used} 個。",
    "No bookmarked files" : "沒有已加書籤的檔案",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "照片或PDF等檔案的書籤將自動保存到您的Nextcloud檔案中，因此即使連結脫機，您仍然可以找到它們。",
    "No broken links" : "沒有失效的連結",
    "No shared folders" : "沒有已分享的資料夾",
    "No duplicated bookmarks" : "沒有書籤複本",
    "No bookmarks here" : "無書籤",
    "Add bookmarks manually or import bookmarks from a HTML file." : "手動添加書籤或從 HTML 檔案導入書籤。",
    "Import" : "匯入",
    "Export" : "導出",
    "Archive path" : "封存路徑",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "輸入應該存儲書籤檔案的資料夾的路徑",
    "Backups" : "備份",
    "Enable bookmarks backups" : "啟用書籤備份",
    "Enter the path of a folder in your Files where backups will be stored." : "輸入在您「檔案」中要儲存備份的資料夾路徑。",
    "Client apps" : "客戶端 apps",
    "Also check out the collection of client apps that integrate with this app: " : "還請檢查與此應用程序集成的客戶端應用程序的集合：",
    "Install web app on device" : "在設備上安裝 web 應用程式",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "您可以在設備主屏幕上安裝此應用程序以快速訪問手機上的書籤。如果您不喜歡它，您可以輕鬆地再次從主屏幕中刪除該應用程式。",
    "Install on home screen" : "在主屏幕上安裝",
    "Bookmarklet" : "書籤",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "將此拖拉到您瀏覽器書籤中且點擊它以快速為網頁添加書籤。",
    "Add to {instanceName}" : "加到 {instanceName}",
    "Backup path" : "備份路徑",
    "Please select \"Add to home screen\" in your browser menu" : "請在瀏覽器菜單中選擇“添加到主屏幕”",
    "Title" : "標題",
    "Link" : "連結",
    "Untitled folder" : "未命名資料夾",
    "Root folder" : "根資料夾",
    "Tags" : "標籤",
    "Select tags and create new ones" : "選擇標籤或創建新標籤",
    "Notes" : "註釋",
    "Notes for this bookmark …" : "此書籤的註釋...",
    "Archived file" : "已封存檔案",
    "Open file" : "開啟檔案",
    "Open file location" : "開啟檔案位置",
    "Projects" : "專案項目",
    "Created {time} ago" : "在 {time} 前創建",
    "Created on {date}" : "創建於 {date} ",
    "Owner" : "擁有者",
    "Sharing" : "分享",
    "Select a user or group" : "選擇用戶或群組",
    "Share link" : "分享連結",
    "Reading allowed" : "允許讀取",
    "Copy RSS feed" : "複製 RSS feed",
    "Delete link" : "刪除連結",
    "Create public link" : "建立公共連結",
    "Resharing allowed" : "允許轉貼分享",
    "Editing allowed" : "允許編輯",
    "Allow editing" : "允許編輯",
    "Allow resharing" : "允許轉貼分享",
    "Remove share" : "移除分享",
    "Link copied" : "連結已複製",
    "Privacy" : "私隱",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "書籤將嘗試存取您添加的網頁，以自動添加有關它們的信息。",
    "Enable accessing and collecting information from the web pages you add" : "從您增加的網頁啟用存取及收集資訊",
    "Performance" : "效能",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "在具有大量用戶的安裝中，限制每個賬戶的書籤數量可能很有用。",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "每個帳號可以允許的書籤最大數量。（0是無限制; 預設是無限制）",
    "Previews" : "預覽",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "為了顯示您添加了書籤的網站的真實屏幕截圖，Bookmarks 可以使用第三方服務來生成預覽。",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "您可以免費在 screeenly。com 註冊或是設定您自己的伺服器。",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API key",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "只要在您的伺服器上安裝 Pageres CLI，書籤應用程式就會找到它。您仍然可以新增額外的 ENV 變數以提供給 pageres，例如在佔位字串中所示：",
    "Pageres ENV variables" : "Pageres ENV 變數",
    "Failed to save settings" : "設定儲存失敗",
    "Failed to load settings" : "載入設定失敗",
    "This URL is already bookmarked! Overwrite?" : "此連結已存在，是否複寫？",
    "Enter bookmark title" : "輸入書籤標題",
    "Enter bookmark URL" : "輸入書籤URL",
    "Folder" : "資料夾",
    "Root Folder" : "根資料夾",
    "Save" : "儲存",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "默認情況下，網絡存取處於停用狀態。轉到書籤應用程式的管理員設置，以啟用獲取預覽和網站圖標的功能。",
    "Link to a bookmark folder" : "連結至書籤資料夾",
    "Failed to count unavailable bookmarks" : "無法點算不可用的書籤",
    "Failed to count archived bookmarks" : "無法點算已封存的書籤",
    "Failed to count duplicated bookmarks" : "無法點算書籤複本",
    "Failed to load bookmark" : "載入書籤失敗",
    "Failed to find existing bookmark" : "尋找現存的書籤失敗",
    "Failed to create bookmark" : "建立書籤失敗",
    "Failed to save bookmark" : "儲存書籤失敗",
    "Failed to move bookmark" : "移動書籤失敗",
    "Failed to copy bookmark" : "無法複製書籤",
    "Failed to delete bookmark" : "刪除書籤失敗",
    "Failed to rename tag" : "重新命名標籤失敗",
    "Failed to load tags" : "載入標記失敗",
    "Failed to load folders" : "載入資料夾失敗",
    "Failed to delete folder" : "刪除資料夾失敗",
    "Failed to create folder" : "建立資料夾失敗",
    "Failed to fetch bookmarks." : "擷取書籤失敗",
    "Failed to change setting" : "變更設定失敗",
    "Failed to load setting {key}" : "載入設定失敗 {key}",
    "Failed to update share {shareId}" : "更新分享失敗 {shareId}",
    "Failed to delete share {shareId}" : "無法刪除分享 {shareId}",
    "Create bookmarks for mentioned links" : "為提到的連結建立書籤",
    "No links found in this message" : "此訊息中找不到連結",
    "Bookmarks feed" : "Bookmarks feed"
},
"nplurals=1; plural=0;");
